<?php
// command/SimpleCommandFactory.php
// qframe license: http://resources.corrosive.co.uk/pkg/qframe/license.txt

require_once 'CommandFactory.php';
require_once '../controller/ApplicationResources.php';

class CommandNotFoundException extends Exception { }

class SimpleCommandFactory extends CommandFactory {
    private $packages = array();
    private $defaultCmd = "DefaultCommand";

    function __construct() {
        array_push( $this->packages, "/usr/local/www/php24/command" );
    }

    function addPackage( $package_str ) {
        array_push( $this->packages, $package_str );
    }

    function setDefaultCommand( $str ) {
        $this->defaultCommand = $str;
    }

    function getDefaultCommand() {
        return $this->defaultCommand;
    }

    function getCommand( RequestHelper $helper ) {
        $cmd = $helper->getCommand();
        if ( empty( $cmd ) ) {
             $cmd = $this->getDefaultCommand();
        }
        return $this->getCommandByName( $cmd );
    }

    private function getCommandByName( $cmd ) {
        foreach ( $this->packages as $package ) {
            $cmdpath = "$package/$cmd.php";
            if ( file_exists( $cmdpath ) ) {
                 require_once $cmdpath;
                 $cmd_obj = new $cmd();
                 if ( is_subclass_of ( $cmd_obj, "Command" ) ) {
                    return $cmd_obj;
                 }
            }
        }
        throw new CommandNotFoundException( "Command: $cmd  " );
     }
}
?>
