<?php

 class Item {
    public $name = "Item";
    private $updater;

    public function setUpdater( ItemUpdater $update ) {
      $this->updater=$update;
    }

    function __destruct() {
       if ( ! empty( $this->updater )) {
          $this->updater->update( $this );
       }
    }
 }

 abstract class ItemUpdater {
    abstract public function update  ( Item $item  );
    abstract public function retrieve( $identifier );
    abstract public function delete  ( Item $item  );
 }

 class ReportItemUpdater extends ItemUpdater {

    public function update( Item $item ) {
       print get_class( $this ) . "::update(): $item->name<br />\n";
       return true;
    }

    public function retrieve( $id ) {
       print get_class( $this ) . "::retrieve(): id $id<br />\n";
       return new Item();
    }

    public function delete( Item $item ) {
       print get_class( $this ) . "::delete(): id $id<br />\n";
       return true;
    }
 }

 class XmlItemUpdater   extends ReportItemUpdater { }

 class MysqlItemUpdater extends ReportItemUpdater { }

 $item = new Item();
 $item->setUpdater( new XmlItemUpdater );
 unset( $item );
 // : "XmlItemUpdater::update(): Item"

 $item = new Item();
 $item->setUpdater( new MysqlItemUpdater );
 unset( $item );
 // : "MysqlItemUpdater::update(): Item"
?>


